@@ -133,8 +133,7 @@ class Microservices(BaseClass, ABC):
         BaseClass.__init__(self, topico, opt.Hosts, topico)
 
         # Inicializar el redis
-        if os.environ.get('REDISVALIDATE', None) is not None:
-            self.initRedis()
+        self.initRedis()
 
         if opt.isNats:
             # iniciar la aplicacion
@@ -155,13 +154,16 @@ class Microservices(BaseClass, ABC):
         """
             Metodo para inicializar el redis
         """
+        self.logs.info("Redis {}".format(
+            os.environ.get('REDISVALIDATE', None)))
+
         if os.environ.get('REDISVALIDATE', None) is None:
             self.logs.warn('No se encuentra activado la validacion por redis')
         else:
             port = os.environ.get('REDIS_PORT', 6379)
 
             __pool_redis = redis.ConnectionPool(
-                host=os.environ.get("REDISVALIDATE"), port=int(port), db=0)
+                host=os.environ.get("REDISVALIDATE"), port=6379, db=0)
             self.redisclient = redis.Redis(connection_pool=__pool_redis)
 
             if self.redisclient is None:
